// List with a context menu project template
import bb.cascades 1.0

NavigationPane {
    id: navigationPane

    Menu.definition: MenuDefinition {

        // Add a Help action

        helpAction: HelpActionItem {
            onTriggered: {

            }
        }

        actions: [
            ActionItem {
                title: qsTr("About")

                onTriggered: {

                }
            }
        ]
    }

    Page {
        id: mainPage

        property string currentDate: today()

        titleBar: TitleBar {
            title : qsTr("ČNB FX rates")
        }

        function today() {
            var date = new Date()

            return formatDate(date)
        }

        function formatDate(date) {
            var result = date.getDate() + "." + (date.getMonth() + 1) + "." + date.getFullYear()

            return result
        }

        function getDayName(date) {
            var d = ['ne','po','út','st', 'čt','pá','so'];
            return d[date.getDay()];
        }

        function reformatDate() {
            var date = new Date()

            var tokens = currentDate.split(".")

            date.setDate(tokens[0])
            date.setMonth(tokens[1]-1)
            date.setFullYear(tokens[2])

            var result = getDayName(date) + ", " + date.getDate() + ". " +
                    (date.getMonth() + 1) + ". " + date.getFullYear()

            return result
        }
        
        content: Container {
            layout: DockLayout {

            }

            ActivityIndicator {
                id: activityIndicator

                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
                preferredWidth: 200
                preferredHeight: 200

                running: !_downloader.firstItemLoaded
            }

            Container {
                layout: StackLayout {
                }

                background: Color.create ("#F6F6F6")

                horizontalAlignment: HorizontalAlignment.Fill

                attachedObjects: [
                    OrientationHandler {
                        id: handler
                    }
                ]

                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }

                    topPadding: 10
                    bottomPadding: 10
                    leftPadding: 10
                    rightPadding: 10

                    DateTimePicker {
                        id: dateTimePicker

                        title: qsTr("Date")
                        //value: picker.dateFromTime(today())

                        onValueChanged: {
                            console.log(mainPage.formatDate(value))
                            _downloader.load(mainPage.formatDate(value))
                        }

                        minimum: "1991-01-01"
                    }

                    Button {
                        text: qsTr("Today")

                        onClicked: {
                            dateTimePicker.dateFromTime(mainPage.today())
                            _downloader.load(mainPage.today())
                        }
                    }
                }

                ListView {
                    horizontalAlignment: HorizontalAlignment.Fill

                    topMargin: 10

                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 6
                    }

                    dataModel: _model

                    listItemComponents: [
                        ListItemComponent {
                            type: "item"


                            // main container
                            Container {
                                layout: DockLayout {
                                }

                                preferredWidth: (OrientationSupport.orientation === UIOrientation.Portrait) ? 750 : 1250

                                horizontalAlignment: HorizontalAlignment.Fill

                                Container {
                                    layout: StackLayout {
                                        orientation: LayoutOrientation.LeftToRight
                                    }

                                    leftPadding: 10
                                    rightPadding: 10
                                    topPadding: 10
                                    bottomPadding: 10

                                    horizontalAlignment: HorizontalAlignment.Left

                                    ImageView {
                                        imageSource: "asset:///images/" + ListItemData.code + ".png"
                                        preferredWidth: 164
                                        preferredHeight: 120

                                        horizontalAlignment: HorizontalAlignment.Left
                                    }

                                    Container {
                                        layout: StackLayout {}

                                        horizontalAlignment: HorizontalAlignment.Left

                                        leftMargin: 10

                                        Label {
                                            text: ListItemData.code

                                            textStyle {
                                                base: SystemDefaults.TextStyles.TitleText
                                                fontWeight: FontWeight.Bold
                                            }

                                            bottomMargin: 0
                                            topMargin: 0
                                        }

                                        Label {
                                            text: ListItemData.country

                                            textStyle {
                                                base: SystemDefaults.TextStyles.SubtitleText
                                            }

                                            bottomMargin: 0
                                            topMargin: 0
                                        }

                                        Label {
                                            text: ListItemData.currency

                                            bottomMargin: 0
                                            topMargin: 0

                                            textStyle {
                                                base: SystemDefaults.TextStyles.SubtitleText
                                                color: Color.Gray
                                                fontStyle: FontStyle.Italic
                                            }
                                        }
                                    }
                                }

                                Container {
                                    layout: StackLayout {
                                        orientation: LayoutOrientation.LeftToRight
                                    }

                                    horizontalAlignment: HorizontalAlignment.Right
                                    verticalAlignment: VerticalAlignment.Center

                                    Label {
                                        text: ListItemData.amount

                                        verticalAlignment: VerticalAlignment.Center

                                        textStyle {
                                            base: SystemDefaults.TextStyles.SubtitleText
                                            color: Color.Gray
                                        }
                                    }

                                    Label {
                                        text: ListItemData.rate

                                        preferredWidth: 265

                                        verticalAlignment: VerticalAlignment.Center
                                        horizontalAlignment: HorizontalAlignment.Right

                                        textStyle {
                                            base: SystemDefaults.TextStyles.BigText
                                            fontWeight: FontWeight.Bold
                                            textAlign: TextAlign.Right
                                        }
                                    }
                                }

                                Divider {
                                    verticalAlignment: VerticalAlignment.Bottom
                                }
                            }
                        }
                    ]

                    onTriggered: {
                        var exchangeRatesPage = exchangeRatePageDefinition.createObject()

                        exchangeRatesPage.exchangeRate = _model.data(indexPath)

                        navigationPane.push(exchangeRatesPage)
                    }

                    enabled: true
                }
            }
        }

        attachedObjects: [
            ComponentDefinition {
                id: appCover
                source: "SceneCover.qml"
            },
            ComponentDefinition {
                id: exchangeRatePageDefinition
                source: "ExchangeRateView.qml"
            }
        ]

        onCreationCompleted: {
            Application.cover = appCover.createObject();

            _downloader.load(today())
        }
    }
}
