#ifndef EXCHANGERATEITEM_H
#define EXCHANGERATEITEM_H

#include <QVariant>
#include <QString>
#include <QObject>
#include <QDebug>

class ExchangeRateItem : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString country READ country WRITE setCountry NOTIFY countryChanged FINAL)
    Q_PROPERTY(QString code READ code WRITE setCode NOTIFY codeChanged FINAL)
    Q_PROPERTY(QString currency READ currency WRITE setCurrency NOTIFY currencyChanged FINAL)
    Q_PROPERTY(int amount READ amount WRITE setAmount NOTIFY amountChanged FINAL)
    Q_PROPERTY(double rate READ rate WRITE setRate NOTIFY rateChanged FINAL)
public:
    ExchangeRateItem(QObject *parent = 0) : QObject(parent) {}

    ExchangeRateItem(QString country, QString code, QString currency, int amount, double rate)
        : QObject(), m_country(country), m_code(code), m_currency(currency), m_amount(amount), m_rate(rate)
    {
    }

    QString country() const {
        return m_country;
    }

    QString code() const {
        return m_code;
    }

    QString currency() const {
        return m_currency;
    }

    int amount() const {
        return m_amount;
    }

    double rate() const {
        return m_rate;
    }

    void setCountry(QString newCountry) {
        if (newCountry != m_country) {
            m_country = newCountry;
            emit countryChanged(m_country);
        }
    }

    void setCode(QString newCode) {
        if (newCode != m_code) {
            m_code = newCode;
            emit codeChanged(m_code);
        }
    }

    void setCurrency(QString newCurrency) {
        if (newCurrency != m_currency) {
            m_currency = newCurrency;
            emit currencyChanged(m_currency);
        }
    }

    void setAmount(int newAmount) {
        if (newAmount != m_amount) {
            m_amount = newAmount;
            emit amountChanged(m_amount);
        }
    }

    void setRate(double newRate) {
        if (newRate != m_rate) {
            m_rate = newRate;
            emit rateChanged(m_rate);
        }
    }

Q_SIGNALS:
    void countryChanged(QString country);
    void codeChanged(QString coder);
    void currencyChanged(QString currency);
    void amountChanged(int amount);
    void rateChanged(double rate);

private:
    QString m_country;
    QString m_code;
    QString m_currency;
    int m_amount;
    double m_rate;

    Q_DISABLE_COPY(ExchangeRateItem)
};

Q_DECLARE_METATYPE( ExchangeRateItem *)

#endif // EXCHANGERATEITEM_H
