#include "ExchangeRatesDownloader.h"
#include "ExchangeRateItem.h"

#include <QVariantMap>
#include <QLocale>

using namespace bb::cascades;

ExchangeRatesDownloader::ExchangeRatesDownloader(QObject *parent) :
    QObject(parent), m_manager(0), m_firstRun(true)
{
    m_model = new GroupDataModel(QStringList() << "country" << "currency");
    m_model->setGrouping(ItemGrouping::None);

    m_topModel = new GroupDataModel(QStringList() << "country" << "currency");
    m_topModel->setGrouping(ItemGrouping::None);
}

void ExchangeRatesDownloader::requestFinished()
{
    qDebug() << "requestFinished";

    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());

    if (!reply) {
        qDebug() << "No reply";

        return;
    }

    if (reply->error() != QNetworkReply::NoError) {
        qDebug() << reply->errorString();

        //emit error();

        return;
    }

    QTextCodec *codec = QTextCodec::codecForName("UTF-8");

    int i = 0;
    QString line;
    while (!reply->atEnd()) {
        line = codec->toUnicode(reply->readLine(100));

        if (i==0) {
            QStringList tokens = line.split(" ");

            m_date = tokens[0] + " " + tokens[1];
            m_revision = tokens[2];

            emit loadedDateChanged(m_date);
        }

        if (i>2) {
            QStringList tokens = line.split("|");

//            QLocale c(QLocale::Czech);

            // exceptional years (EU)
            if (tokens.count() > 1)
                if (!tokens.contains("denominace")) { // naznacit, ze se jedna o neco jineho
                    ExchangeRateItem *item = new ExchangeRateItem(tokens[0], tokens[3], tokens[1], tokens[2].toInt(), tokens[4].toDouble());

                    if (i == 3) {
                        m_firstItemLoaded = true;
                        emit firstItemLoadedChanged(m_firstItemLoaded);
                    }

                    m_model->insert(item);

                    // top model only for current day as the first load is today
                    if (m_firstRun) {
                        if ((item->code() == "USD") || (item->code() == "GBP") || (item->code() == "EUR"))
                            m_topModel->insert(item);
                    }
                }
        }

        i++;
    }

    m_firstRun = false;

    reply->deleteLater();
}

void ExchangeRatesDownloader::load(const QString formattedDate)
{
    qDebug() << "Loading model for date " + formattedDate;


    QNetworkConfigurationManager m;
    qDebug() << "Online:" << m.isOnline();

    if (m_model) {
        m_model->clear();
    }

    if (!m_manager)
        m_manager = new QNetworkAccessManager(this);

    if (!m_manager) {
        qDebug() << "Failed to create network manager";

                return;
    }

    m_firstItemLoaded = false;
    emit firstItemLoadedChanged(m_firstItemLoaded);

    QString language = QLocale().name().left(2);
    qDebug() << language;

    QUrl url;

    if (language == "en") {
        url.setUrl("http://www.cnb.cz/en/financial_markets/foreign_exchange_market/exchange_rate_fixing/daily.txt?date=" + formattedDate);
    } else
    {
        url.setUrl("http://www.cnb.cz/cs/financni_trhy/devizovy_trh/kurzy_devizoveho_trhu/denni_kurz.txt?date=" + formattedDate);
    }

    qDebug() << url.toString();

    QNetworkRequest request(url);

    if (m_manager) {
        QNetworkReply* reply = m_manager->get(request);

        connect(reply, SIGNAL(finished()), this, SLOT(requestFinished()));
    }
    else
        qDebug() << "No network manager";
}

bb::cascades::GroupDataModel *ExchangeRatesDownloader::model()
{
    return m_model;
}

bb::cascades::GroupDataModel *ExchangeRatesDownloader::topModel()
{
    return m_topModel;
}
